==> efs-1.60.0-sources.jar: software/amazon/awscdk/services/efs/LifecyclePolicy.java <==
package software.amazon.awscdk.services.efs;

/**
 * EFS Lifecycle Policy, if a file is not accessed for given days, it will move to EFS Infrequent Access.
 * <p>
 * EXPERIMENTAL
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-elasticfilesystem-filesystem-lifecyclepolicies
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.234Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.LifecyclePolicy")
public enum LifecyclePolicy {
    /**
     * After 7 days of not being accessed.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_7_DAYS,
    /**
     * After 14 days of not being accessed.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_14_DAYS,
    /**
     * After 30 days of not being accessed.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_30_DAYS,
    /**
     * After 60 days of not being accessed.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_60_DAYS,
    /**
     * After 90 days of not being accessed.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_90_DAYS,
}

==> efs-1.93.0-sources.jar: software/amazon/awscdk/services/efs/LifecyclePolicy.java <==
package software.amazon.awscdk.services.efs;

/**
 * (experimental) EFS Lifecycle Policy, if a file is not accessed for given days, it will move to EFS Infrequent Access.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-elasticfilesystem-filesystem-lifecyclepolicies
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.420Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.LifecyclePolicy")
public enum LifecyclePolicy {
    /**
     * (experimental) After 7 days of not being accessed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_7_DAYS,
    /**
     * (experimental) After 14 days of not being accessed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_14_DAYS,
    /**
     * (experimental) After 30 days of not being accessed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_30_DAYS,
    /**
     * (experimental) After 60 days of not being accessed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_60_DAYS,
    /**
     * (experimental) After 90 days of not being accessed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    AFTER_90_DAYS,
}
